a <- function(x, #
              y) {
  x - 1
}


a <- function(x, #
              y) #
{
  x
}

a <- function(x, #
              y #
) {
  y
}


a <- function(x,
              y) {
  x - 1
}

a <- function(x,
              #
              y) {
  x - 1
}

a <- function(x,
              y) {
  x - 1
}


a <- function(x,
              y) {
  x - 1
}

a <- function(
    #
    x,
    y) {
  x - 1
}
